@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -40,11 +40,11 @@ struct _AviFrame
     avi_edit,AVI編集ハンドル
          RET,AVIフレーム構造体,NULL:エラー                                  */
 AviFrame *
-avi_get_frame_open (AviEdit *avi_edit)
+avi_frame_open (AviEdit *avi_edit)
 {
   AviFrame *avi_frame;
 
-  if (!avi_edit || avi_type (avi_edit) != AVI_TYPE_VIDEO)
+  if (!avi_edit || avi_edit_type (avi_edit) != AVI_TYPE_VIDEO)
     return NULL;
   avi_frame = g_malloc0 (sizeof (AviFrame));
   avi_frame->pos = -1;
@@ -57,7 +57,7 @@ avi_get_frame_open (AviEdit *avi_edit)
     avi_frame,AVIフレーム構造体
           RET,TRUE:正常終了,FALSE:エラー                                    */
 gboolean
-avi_get_frame_close (AviFrame *avi_frame)
+avi_frame_close (AviFrame *avi_frame)
 {
   if (!avi_frame)
     return FALSE;
@@ -77,55 +77,44 @@ avi_get_frame_close (AviFrame *avi_frame)
           pos,取得するフレーム(サンプル番号)
           RET,パックDIBへのポインタ,NULL:エラー                             */
 static BitmapInfoHeader *
-avi_get_frame_real (AviFrame   *avi_frame,
-                    const gint  pos)
+avi_frame_get_bitmap_real (AviFrame   *avi_frame,
+                           const gint  pos)
 {
-  gpointer input = NULL, output;
-  gint i, j, size;
+  gint i, size;
   AviEdit *avi_edit;
   BitmapInfoHeader *bmih;
 
   avi_edit = avi_frame->avi_edit;
-  if (pos < 0 || avi_length (avi_edit) <= pos)
+  if (pos < 0 || avi_edit_length (avi_edit) <= pos)
     return NULL;                    /* ja:範囲外 */
-  avi_get_file (avi_edit, pos);     /* ja:AVIファイルを求める */
+  avi_base_get_file (avi_edit, pos);/* ja:AVIファイルを求める */
   if (avi_edit->file->handler == AVI_STREAM_COMP_DIB)
     {
-      /* ja:ヌルフレームのチェック */
-      for (i = pos - avi_edit->offset + avi_edit->file->start; i > 0; i--)
-        if (avi_edit->file->index[i].size > 0)
-          break;
+      gint header;
+
       /* ja:イメージのサイズよりもデータのサイズが小さいときエラー */
-      if (bm_image_bytes (avi_edit->file->bmih)
-                                            > avi_edit->file->index[i].size)
+      size = avi_read_video_size (avi_edit->file, pos - avi_edit->offset);
+      if (size < bm_image_bytes (avi_edit->file->bmih))
         return NULL;
-      size = bm_header_bytes (avi_edit->file->bmih);
-      bmih = g_malloc (size + avi_edit->file->index[i].size);
+      header = bm_header_bytes (avi_edit->file->bmih);
+      bmih = g_malloc (header + size);
       /* ja:ヘッタ */
-      g_memmove (bmih, avi_edit->file->bmih, size);
+      g_memmove (bmih, avi_edit->file->bmih, header);
       if (bmih_get_compression (bmih) == AVI_STREAM_COMP_DIB)
         bmih_set_compression (bmih, BI_COMP_RGB);
-      if (bmih_get_size_image (bmih) <= 0)
-        bmih_set_size_image (bmih, bm_image_bytes (bmih));
       /* ja:イメージ */
-      if (!avi_edit->file->data)
+      if (!avi_read_video (avi_edit->file, pos - avi_edit->offset,
+                                                    (guint8 *)bmih + header))
         {
-          /* ja:ファイル */
-          fileio_seek (avi_edit->file->fio, avi_edit->file->index[i].offset,
-                                                            FILEIO_SEEK_SET);
-          fileio_read (avi_edit->file->fio, (guint8 *)bmih + size,
-                                                avi_edit->file->index[i].size);
-        }
-      else
-        {
-          /* ja:メモリ */
-          g_memmove ((guint8 *)bmih + size,
-            (guint8 *)avi_edit->file->data + avi_edit->file->index[i].offset,
-                                                avi_edit->file->index[i].size);
+          g_free (bmih);
+          return NULL;
         }
     }
   else
     {
+      gpointer input = NULL, output;
+      gint j;
+
       if (avi_edit->file->handler != avi_frame->handler)
         {
           /* ja:圧縮が異なるとき */
@@ -180,7 +169,7 @@ avi_get_frame_real (AviFrame   *avi_frame,
       if (avi_frame->pos != pos - 1 || pos <= avi_edit->offset)
         while (j > 0)
           { /* ja:連続していないとき */
-            if ((avi_edit->file->index[j].flags & AVI_IF_KEYFRAME)
+            if (avi_edit->file->index[j].key
                                         && avi_edit->file->index[j].size > 0)
               break;
             j--;
@@ -194,23 +183,15 @@ avi_get_frame_real (AviFrame   *avi_frame,
             {
               /* ja:イメージ */
               input = g_realloc (input, avi_edit->file->index[j].size);
-              if (!avi_edit->file->data)
+              if (!avi_read_video (avi_edit->file,
+                                            j - avi_edit->file->start, input))
                 {
-                  /* ja:ファイル */
-                  fileio_seek (avi_edit->file->fio,
-                            avi_edit->file->index[j].offset, FILEIO_SEEK_SET);
-                  fileio_read (avi_edit->file->fio, input,
-                                                avi_edit->file->index[j].size);
-                }
-              else
-                {
-                  /* ja:メモリ */
-                  g_memmove (input, (guint8 *)avi_edit->file->data
-                                            + avi_edit->file->index[j].offset,
-                                                avi_edit->file->index[j].size);
+                  g_free (input);
+                  g_free (bmih);
+                  return NULL;
                 }
               icm_decompress (avi_frame->icm_object,
-                        avi_edit->file->index[j].flags & AVI_IF_KEYFRAME
+                        avi_edit->file->index[j].key
                                             ? 0 : ICM_DECOMPRESS_NOTKEYFRAME,
                                                                 input, output);
             }
@@ -230,14 +211,14 @@ avi_get_frame_real (AviFrame   *avi_frame,
     bit_count,色数
           RET,パックDIBへのポインタ,NULL:エラー                             */
 BitmapInfoHeader *
-avi_get_frame (AviFrame   *avi_frame,
-               const gint  pos,
-               const gint  width,
-               const gint  height,
-               const gint  bit_count)
+avi_frame_get_bitmap (AviFrame   *avi_frame,
+                      const gint  pos,
+                      const gint  width,
+                      const gint  height,
+                      const gint  bit_count)
 {
   gint i, n;
-  AviBuffer avi_buf;
+  AviCache avi_buf;
   AviEdit *avi_edit;
   BitmapInfoHeader *bmih0, *bmih1;
 
@@ -245,7 +226,7 @@ avi_get_frame (AviFrame   *avi_frame,
     return NULL;
   avi_edit = avi_frame->avi_edit;
   /* ja:ヌルフレームのチェック */
-  avi_get_file (avi_edit,pos);      /* ja:AVIファイルを求める */
+  avi_base_get_file (avi_edit,pos);/* ja:AVIファイルを求める */
   for (n = pos-avi_edit->offset + avi_edit->file->start; n > 0; n--)
     if (avi_edit->file->index[n].size > 0)
       break;
@@ -260,13 +241,13 @@ avi_get_frame (AviFrame   *avi_frame,
         {
           /* ja:キャッシュに同じものがあるとき */
           avi_buf = avi_edit->buf[i];
-          g_memmove (avi_edit->buf + 1, avi_edit->buf, i * sizeof (AviBuffer));
+          g_memmove (avi_edit->buf + 1, avi_edit->buf, i * sizeof (AviCache));
           avi_edit->buf[0] = avi_buf;
           return avi_buf.data;
         }
 
   /* ja:展開された元のフレームを取得 */
-  bmih0 = avi_get_frame_real (avi_frame,pos);
+  bmih0 = avi_frame_get_bitmap_real (avi_frame, pos);
   if (!bmih0)
     return NULL;
 
@@ -328,7 +309,7 @@ avi_get_frame (AviFrame   *avi_frame,
     }
   g_free (avi_edit->buf[AVI_EDIT_CACHE-1].data);
   g_memmove (avi_edit->buf + 1, avi_edit->buf,
-                                    (AVI_EDIT_CACHE - 1) * sizeof (AviBuffer));
+                                    (AVI_EDIT_CACHE - 1) * sizeof (AviCache));
   avi_edit->buf[0].data = bmih0;
   avi_edit->buf[0].raw = FALSE;
   avi_edit->buf[0].pos = pos;
@@ -343,15 +324,15 @@ avi_get_frame (AviFrame   *avi_frame,
        height,高さ
           RET,RAWへのポインタ,NULL:エラー                               */
 guint8 *
-avi_get_frame32 (AviFrame  *avi_frame,
-                const gint  pos,
-                const gint  width,
-                const gint  height)
+avi_frame_get_raw (AviFrame  *avi_frame,
+                   const gint  pos,
+                   const gint  width,
+                   const gint  height)
 {
   gint i, n, xx, yy, src, dst;
   guchar *p;
   guint8 *q;
-  AviBuffer avi_buf;
+  AviCache avi_buf;
   AviEdit *avi_edit;
   BitmapInfoHeader *bmih;
 
@@ -359,11 +340,11 @@ avi_get_frame32 (AviFrame  *avi_frame,
     return NULL;
   avi_edit = avi_frame->avi_edit;
   /* ja:ヌルフレームのチェック */
-  avi_get_file (avi_edit, pos);     /* ja:AVIファイルを求める */
+  avi_base_get_file (avi_edit, pos);/* ja:AVIファイルを求める */
   for (n = pos - avi_edit->offset + avi_edit->file->start; n > 0; n--)
     if (avi_edit->file->index[n].size > 0)
         break;
-    n += avi_edit->offset - avi_edit->file->start;
+  n += avi_edit->offset - avi_edit->file->start;
   /* ja:バッファをチェック */
   for (i = 0; i < AVI_EDIT_CACHE && avi_edit->buf[i].data; i++)
     if ((avi_edit->buf[i].pos == n || avi_edit->buf[i].pos == pos)
@@ -373,11 +354,11 @@ avi_get_frame32 (AviFrame  *avi_frame,
       {
         /* ja:キャッシュに同じものがあるとき */
         avi_buf = avi_edit->buf[i];
-        g_memmove (avi_edit->buf + 1, avi_edit->buf, i * sizeof (AviBuffer));
+        g_memmove (avi_edit->buf + 1, avi_edit->buf, i * sizeof (AviCache));
         avi_edit->buf[0] = avi_buf;
         return avi_buf.data;
       }
-  bmih = avi_get_frame (avi_frame, pos, width, height, 32);
+  bmih = avi_frame_get_bitmap (avi_frame, pos, width, height, 32);
   if (!bmih)
     return NULL;
   p = g_malloc (width * height * 4 * sizeof (guchar));
@@ -406,16 +387,15 @@ avi_get_frame32 (AviFrame  *avi_frame,
          pos,取得するフレーム(サンプル番号)
          RET,TRUE:キーフレーム,FALSE:非キーフレーム                         */
 gboolean
-avi_is_keyframe (AviEdit    *avi_edit,
-                 const gint  pos)
+avi_frame_is_key (AviEdit    *avi_edit,
+                  const gint  pos)
 {
-  if (avi_edit && avi_type (avi_edit) == AVI_TYPE_VIDEO)
+  if (avi_edit && avi_edit_type (avi_edit) == AVI_TYPE_VIDEO)
     {
       /* ja:ビデオ */
-      avi_get_file (avi_edit, pos);/* ja:AVIファイルを求める */
+      avi_base_get_file (avi_edit, pos);/* ja:AVIファイルを求める */
       return avi_edit->file->index
-                        [pos-avi_edit->offset + avi_edit->file->start].flags
-                                                            & AVI_IF_KEYFRAME;
+                        [pos - avi_edit->offset + avi_edit->file->start].key;
     }
   return TRUE;
 }
