@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -28,7 +28,8 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-#define WAVE_FORMAT_PCM 1
+#define WAVE_FMT_UNKNOWN 0
+#define WAVE_FMT_PCM     1
 
 
 #define WFX_SIZE 18
@@ -78,7 +79,7 @@ typedef struct _WaveConv WaveConv;
                             GUINT16_FROM_LE(*(guint16 *)((guint8 *)(wfx)+14))
 #define wfx_get_size(wfx) GUINT16_FROM_LE(*(guint16 *)((guint8 *)(wfx)+16))
 #define wfx_set_format_tag(wfx,format_tag)                                  \
-                                (*(guint16 *)(wfx))=GUINT16_TO_LE(format_tag))
+                                (*(guint16 *)(wfx)=GUINT16_TO_LE(format_tag))
 #define wfx_set_channels(wfx,channels)                                      \
                     (*(guint16 *)((guint8 *)(wfx)+2)=GUINT16_TO_LE(channels))
 #define wfx_set_samples_per_sec(wfx,samples_per_sec)                        \
@@ -104,6 +105,29 @@ typedef struct _WaveConv WaveConv;
 #define wf_header_bytes(wfx) (wfx_get_size(wfx)+WFX_SIZE)
 
 
+/*  ja:WaveFormatEx構造体を比較する
+    wfx0,WaveFormatEx構造体へのポインタ
+    wfx1,WaveFormatEx構造体へのポインタ
+     RET,TRUE:同じ,FALSE:異なる                                             */
+#define wf_header_cmp(wfx0,wfx1)                                            \
+                            (wf_header_bytes(wfx0)==wf_header_bytes(wfx1)   \
+                                &&g_memcmp(wfx0,wfx1,wf_header_bytes(wfx0))==0)
+
+
+/******************************************************************************
+*                                                                             *
+* ja:PCM生成関数                                                              *
+*                                                                             *
+******************************************************************************/
+/*  ja:無音PCMを作る
+        wfx,WaveFormatEx構造体へのポインタ
+    samples,出力データのサンプル数
+        RET,無音のPCM                                                       */
+gpointer
+wave_fill_silent_pcm (WaveFormatEx *wfx,
+                      const gsize   samples);
+
+
 /******************************************************************************
 *                                                                             *
 * ja:PCM加工関数                                                              *
@@ -127,10 +151,10 @@ wave_convert_begin (WaveFormatEx *wfx0,
             RET,TRUE:正常終了,FALSE:エラー                                  */
 gboolean
 wave_convert (WaveConv      *wcv,
-              gpointer       in_buf,
-              const gint     in_samples,
+              gconstpointer  in_buf,
+              const gsize    in_samples,
               gpointer      *out_buf,
-              gint          *out_samples);
+              gsize         *out_samples);
 
 
 /*  ja:PCMの変換を終了する
@@ -141,7 +165,7 @@ wave_convert (WaveConv      *wcv,
 gboolean
 wave_convert_end (WaveConv *wcv,
                   gpointer *out_buf,
-                  gint     *out_samples);
+                  gsize    *out_samples);
 
 
 /*  ja:PCMの変換をする
@@ -155,10 +179,10 @@ wave_convert_end (WaveConv *wcv,
 gboolean
 wave_convert_direct (WaveFormatEx  *wfx0,
                      WaveFormatEx  *wfx1,
-                     gpointer       in_buf,
-                     const gint     in_samples,
+                     gconstpointer  in_buf,
+                     const gsize    in_samples,
                      gpointer      *out_buf,
-                     gint          *out_samples);
+                     gsize         *out_samples);
 
 
 #ifdef __cplusplus
