@@ -1,6 +1,6 @@
 /*
     orzmdi
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,8 +16,8 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
-#include "misc/fileio.h"
 #include "orzmdi.h"
+#include "misc/fileio.h"
 
 
 static void orz_mdi_class_init (OrzMdiClass *klass);
@@ -70,13 +70,21 @@ orz_mdi_label_markup (OrzMdiTab *tab)
 
   if (tab->same < -1)
     {
+#if GLIB_CHECK_VERSION(2,6,0)
+      label = g_filename_display_basename (tab->file);
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
       str = g_path_get_basename (tab->file);
       label = g_filename_to_utf8 (str, -1, NULL, NULL, NULL);
       g_free (str);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
     }
   else
     {
+#if GLIB_CHECK_VERSION(2,6,0)
+      label = g_filename_display_name (tab->file);
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
       label = g_filename_to_utf8 (tab->file, -1, NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
     }
   if (tab->edited)
     {
@@ -264,6 +272,36 @@ orz_mdi_get_type (void)
 }
 
 
+/* ja:子ウィジェットが破棄されるとき */
+static void
+orz_mdi_remove (GtkContainer *container,
+                GtkWidget    *widget)
+{
+  GtkWidget *tab_label;
+
+  tab_label = gtk_notebook_get_tab_label (GTK_NOTEBOOK (container), widget);
+  if (tab_label)
+    {
+      OrzMdiTab *tab;
+
+      tab = g_object_get_data (G_OBJECT (tab_label), "user_data");
+      if (tab)
+        {
+          g_signal_emit (container,
+                    orz_mdi_signals[REMOVE_WINDOW_SIGNAL],
+                    0,
+                    gtk_notebook_page_num (GTK_NOTEBOOK (container), widget),
+                    tab->page_data);
+          file_remove_edit (ORZ_MDI (container), tab, NULL);
+          g_free (tab->file);
+          g_free (tab);
+          g_object_set_data (G_OBJECT (tab_label), "user_data", NULL);
+        }
+    }
+  ((GtkContainerClass *)parent_class)->remove (container, widget);
+}
+
+
 static void
 orz_mdi_switch_page (GtkNotebook     *notebook,
                      GtkNotebookPage *page,
@@ -300,15 +338,18 @@ orz_mdi_class_init (OrzMdiClass *klass)
   GObjectClass *gobject_class;
   GtkObjectClass *object_class;
   GtkWidgetClass *widget_class;
+  GtkContainerClass *container_class;
   GtkNotebookClass *notebook_class;
 
-  gobject_class = (GObjectClass*) klass;
-  object_class = (GtkObjectClass*) klass;
-  widget_class = (GtkWidgetClass*) klass;
-  notebook_class = (GtkNotebookClass*) klass;
+  gobject_class = (GObjectClass *) klass;
+  object_class = (GtkObjectClass *) klass;
+  widget_class = (GtkWidgetClass *) klass;
+  container_class = (GtkContainerClass *) klass;
+  notebook_class = (GtkNotebookClass *) klass;
 
   parent_class = g_type_class_peek_parent (klass);
 
+  container_class->remove = orz_mdi_remove;
   notebook_class->switch_page = orz_mdi_switch_page;
 
   orz_mdi_signals[ADD_WINDOW_SIGNAL]
@@ -442,7 +483,7 @@ orz_mdi_destroy (GtkWidget *widget,
 
 
 /* ja:ドロップされたとき */
-void
+static void
 orz_mdi_tab_drag_begin (GtkWidget      *widget,
                         GdkDragContext *context,
                         gpointer        user_data)
@@ -451,7 +492,7 @@ orz_mdi_tab_drag_begin (GtkWidget      *widget,
   OrzMdiTab *tab;
 
   tab = g_object_get_data (G_OBJECT (widget), "user_data");
-  pixbuf = fileio_extract_icon (tab->file, FILEIO_ICON_SIZE_LARGE);
+  pixbuf = fileio_extract_icon (tab->file, GTK_ICON_SIZE_DND);
   if (pixbuf)
     {
       gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
@@ -469,7 +510,8 @@ orz_mdi_tab_drag_data_get (GtkWidget        *widget,
   const static gchar *text = "dummy";
 
   if (info == TARGET_ORZ_MDI_TAB)
-    gtk_selection_data_set (data, data->target, 8, text, g_strlen (text));
+    gtk_selection_data_set (data, data->target, 8,
+                                        (const guchar *)text, g_strlen (text));
 }
 static void
 orz_mdi_tab_drag_data_received (GtkWidget        *widget,
@@ -509,11 +551,11 @@ orz_mdi_tab_drag_data_received (GtkWidget        *widget,
     page_data,ページデータ
           RET,ウィジェット                                                  */
 static GtkWidget *
-orz_mdi_create_tab_label (OrzMdi      *mdi,
-                          GtkWidget   *child,
-                          const gchar *file,
-                          gboolean     created,
-                          gpointer     page_data)
+orz_mdi_create_tab_label (OrzMdi         *mdi,
+                          GtkWidget      *child,
+                          const gchar    *file,
+                          const gboolean  created,
+                          gpointer        page_data)
 {
   GdkPixbuf *pixbuf;
   GtkIconSet *icon_set;
@@ -541,7 +583,7 @@ orz_mdi_create_tab_label (OrzMdi      *mdi,
                                          gtk_widget_get_default_style (),
                                          GTK_TEXT_DIR_NONE,
                                          GTK_STATE_NORMAL,
-                                         GTK_ICON_SIZE_BUTTON,
+                                         GTK_ICON_SIZE_MENU,
                                          NULL, NULL);
       if (pixbuf)
         {
@@ -603,7 +645,7 @@ orz_mdi_create_tab_label (OrzMdi      *mdi,
         }
     }
   if (!image)
-    image = gtk_image_new_from_stock (GTK_STOCK_CDROM, GTK_ICON_SIZE_BUTTON);
+    image = gtk_image_new_from_stock (GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU);
   if (!image)
     {
       const static gchar *xpm[] = {
@@ -640,7 +682,7 @@ orz_mdi_create_tab_label (OrzMdi      *mdi,
   orz_mdi_label_markup (tab);
   gtk_widget_show (tab->label);
   /* ja:アイコン */
-  pixbuf = fileio_extract_icon (tab->file, FILEIO_ICON_SIZE_SMALL);
+  pixbuf = fileio_extract_icon (tab->file, GTK_ICON_SIZE_BUTTON);
   if (pixbuf)
     {
       tab->image = gtk_image_new_from_pixbuf (pixbuf);
@@ -680,6 +722,107 @@ orz_mdi_create_tab_label (OrzMdi      *mdi,
 }
 
 
+/*  ja:ページを最後に追加する
+          mdi,ウィジェット
+        child,内容
+         file,ファイル名
+      created,TRUE:新規作成,FALSE:既存ファイル
+    page_data,ページデータ
+          RET,ページ(0...,-1:エラー)                                        */
+gint
+orz_mdi_append_page (OrzMdi         *mdi,
+                     GtkWidget      *child,
+                     const gchar    *file,
+                     const gboolean  created,
+                     gpointer        page_data)
+{
+  return orz_mdi_insert_page_menu (mdi, child, NULL, -1,
+                                                    file, created, page_data);
+}
+
+
+/*  ja:ページを最後に追加する
+          mdi,ウィジェット
+        child,内容
+         menu,メニュー
+         file,ファイル名
+      created,TRUE:新規作成,FALSE:既存ファイル
+    page_data,ページデータ
+          RET,ページ(0...,-1:エラー)                                        */
+gint
+orz_mdi_append_page_menu (OrzMdi         *mdi,
+                          GtkWidget      *child,
+                          GtkWidget      *menu,
+                          const gchar    *file,
+                          const gboolean  created,
+                          gpointer        page_data)
+{
+  return orz_mdi_insert_page_menu (mdi, child, menu, -1,
+                                                    file, created, page_data);
+}
+
+
+/*  ja:ページを最初に追加する
+          mdi,ウィジェット
+        child,内容
+         file,ファイル名
+      created,TRUE:新規作成,FALSE:既存ファイル
+    page_data,ページデータ
+          RET,ページ(0...,-1:エラー)                                        */
+gint
+orz_mdi_prepend_page (OrzMdi         *mdi,
+                      GtkWidget      *child,
+                      const gchar    *file,
+                      const gboolean  created,
+                      gpointer        page_data)
+{
+  return orz_mdi_insert_page_menu (mdi, child, NULL, 0,
+                                                    file, created, page_data);
+}
+
+
+/*  ja:ページを最初に追加する
+          mdi,ウィジェット
+        child,内容
+         menu,メニュー
+         file,ファイル名
+      created,TRUE:新規作成,FALSE:既存ファイル
+    page_data,ページデータ
+          RET,ページ(0...,-1:エラー)                                        */
+gint
+orz_mdi_prepend_page_menu (OrzMdi         *mdi,
+                           GtkWidget      *child,
+                           GtkWidget      *menu,
+                           const gchar    *file,
+                           const gboolean  created,
+                           gpointer        page_data)
+{
+  return orz_mdi_insert_page_menu (mdi, child, menu, 0,
+                                                    file, created, page_data);
+}
+
+
+/*  ja:ページを挿入する
+          mdi,ウィジェット
+        child,内容
+     position,位置(0...)
+         file,ファイル名
+      created,TRUE:新規作成,FALSE:既存ファイル
+    page_data,ページデータ
+       RET,ページ(0...,-1:エラー)                                           */
+gint
+orz_mdi_insert_page (OrzMdi         *mdi,
+                     GtkWidget      *child,
+                     const gint      position,
+                     const gchar    *file,
+                     const gboolean  created,
+                     gpointer        page_data)
+{
+  return orz_mdi_insert_page_menu (mdi, child, NULL, position,
+                                                    file, created, page_data);
+}
+
+
 /*  ja:ページを挿入する
           mdi,ウィジェット
         child,内容
@@ -690,13 +833,13 @@ orz_mdi_create_tab_label (OrzMdi      *mdi,
     page_data,ページデータ
        RET,ページ(0...,-1:エラー)                                           */
 gint
-orz_mdi_insert_page_menu (OrzMdi      *mdi,
-                          GtkWidget   *child,
-                          GtkWidget   *menu,
-                          gint         position,
-                          const gchar *file,
-                          gboolean     created,
-                          gpointer     page_data)
+orz_mdi_insert_page_menu (OrzMdi         *mdi,
+                          GtkWidget      *child,
+                          GtkWidget      *menu,
+                          const gint      position,
+                          const gchar    *file,
+                          const gboolean  created,
+                          gpointer        page_data)
 {
   gint page_num = -1;
   GtkWidget *tab_label;
@@ -716,13 +859,15 @@ orz_mdi_insert_page_menu (OrzMdi      *mdi,
 }
 
 
-#if !GTK_CHECK_VERSION(2,2,0)
 /*  ja:ページ数を取得する
     mdi,ウィジェット
     RET,ページ数                                                            */
 gint
 orz_mdi_get_n_pages (OrzMdi *mdi)
 {
+#if GTK_CHECK_VERSION(2,2,0)
+  return gtk_notebook_get_n_pages (GTK_NOTEBOOK (mdi));
+#else /* not GTK_CHECK_VERSION(2,2,0) */
   gint n_pages = 0;
 
   if (mdi)
@@ -737,8 +882,8 @@ orz_mdi_get_n_pages (OrzMdi *mdi)
         }
     }
   return n_pages;
-}
 #endif /* not GTK_CHECK_VERSION(2,2,0) */
+}
 
 
 /*  ja:ページをデータから取得する
@@ -766,8 +911,8 @@ orz_mdi_get_page_from_data (OrzMdi  *mdi,
     page_num,ページ(0...),-1:カレント
          RET,ページ内部データ                                               */
 static OrzMdiTab *
-orz_mdi_get_tab (OrzMdi *mdi,
-                 gint    page_num)
+orz_mdi_get_tab (OrzMdi     *mdi,
+                 const gint  page_num)
 {
   if (mdi)
     {
@@ -793,13 +938,13 @@ orz_mdi_get_tab (OrzMdi *mdi,
     page_num,ページ(0...),-1:カレント
          RET,ページデータ                                                   */
 gpointer
-orz_mdi_get_data (OrzMdi *mdi,
-                  gint    page_num)
+orz_mdi_get_data (OrzMdi     *mdi,
+                  const gint  page_num)
 {
   OrzMdiTab *tab;
 
   tab = orz_mdi_get_tab (mdi, page_num);
-  return tab ? tab->page_data: NULL;
+  return tab ? tab->page_data : NULL;
 }
 
 
@@ -809,9 +954,9 @@ orz_mdi_get_data (OrzMdi *mdi,
      page_data,ページデータ
            RET,TRUE:正常終了,FALSE:エラー                                   */
 gboolean
-orz_mdi_set_data (OrzMdi  *mdi,
-                  gint     page_num,
-                  gpointer page_data)
+orz_mdi_set_data (OrzMdi     *mdi,
+                  const gint  page_num,
+                  gpointer    page_data)
 {
   OrzMdiTab *tab;
 
@@ -830,8 +975,8 @@ orz_mdi_set_data (OrzMdi  *mdi,
     page_num,ページ(0...),-1:カレント
          RET,ファイル名,NULL:エラー                                         */
 const gchar *
-orz_mdi_get_file (OrzMdi *mdi,
-                  gint    page_num)
+orz_mdi_get_file (OrzMdi     *mdi,
+                  const gint  page_num)
 {
   OrzMdiTab *tab;
 
@@ -847,7 +992,7 @@ orz_mdi_get_file (OrzMdi *mdi,
          RET,TRUE:正常終了,FALSE:エラー                                     */
 gboolean
 orz_mdi_set_file (OrzMdi      *mdi,
-                  gint         page_num,
+                  const gint   page_num,
                   const gchar *file)
 {
   if (mdi && file)
@@ -888,7 +1033,7 @@ orz_mdi_set_file (OrzMdi      *mdi,
                     gtk_container_remove (GTK_CONTAINER (hbox), tab->image);
                   tab->image = NULL;
                   pixbuf = fileio_extract_icon (tab->file,
-                                                    FILEIO_ICON_SIZE_SMALL);
+                                                        GTK_ICON_SIZE_BUTTON);
                   if (pixbuf)
                     {
                       tab->image = gtk_image_new_from_pixbuf (pixbuf);
@@ -917,8 +1062,8 @@ orz_mdi_set_file (OrzMdi      *mdi,
     page_num,ページ(0...),-1:カレント
          RET,TRUE:新規作成,FALSE:既存ファイル                               */
 gboolean
-orz_mdi_get_created (OrzMdi *mdi,
-                     gint    page_num)
+orz_mdi_get_created (OrzMdi     *mdi,
+                     const gint  page_num)
 {
   OrzMdiTab *tab;
 
@@ -933,9 +1078,9 @@ orz_mdi_get_created (OrzMdi *mdi,
     is_create,TRUE:新規作成,FALSE:既存ファイル
           RET,TRUE:正常終了,FALSE:エラー                                    */
 gboolean
-orz_mdi_set_created (OrzMdi   *mdi,
-                     gint      page_num,
-                     gboolean  is_create)
+orz_mdi_set_created (OrzMdi         *mdi,
+                     const gint      page_num,
+                     const gboolean  is_create)
 {
   OrzMdiTab *tab;
 
@@ -955,8 +1100,8 @@ orz_mdi_set_created (OrzMdi   *mdi,
     page_num,ページ(0...),-1:カレント
          RET,TRUE:編集済み,FALSE:未編集                                     */
 gboolean
-orz_mdi_get_edited (OrzMdi *mdi,
-                    gint    page_num)
+orz_mdi_get_edited (OrzMdi     *mdi,
+                    const gint  page_num)
 {
   OrzMdiTab *tab;
 
@@ -971,9 +1116,9 @@ orz_mdi_get_edited (OrzMdi *mdi,
      is_edit,TRUE:編集済み,FALSE:未編集
          RET,TRUE:正常終了,FALSE:エラー                                     */
 gboolean
-orz_mdi_set_edited (OrzMdi   *mdi,
-                    gint      page_num,
-                    gboolean  is_edit)
+orz_mdi_set_edited (OrzMdi         *mdi,
+                    const gint      page_num,
+                    const gboolean  is_edit)
 {
   OrzMdiTab *tab;
 
@@ -997,9 +1142,9 @@ orz_mdi_set_edited (OrzMdi   *mdi,
     page_num_dst,移動先ページ(0...),-1:末尾
              RET,TRUE:正常終了,FALSE:エラー                                 */
 gboolean
-orz_mdi_reorder (OrzMdi *mdi,
-                 gint    page_num_src,
-                 gint    page_num_dst)
+orz_mdi_reorder (OrzMdi     *mdi,
+                 const gint  page_num_src,
+                 const gint  page_num_dst)
 {
   OrzMdiTab *tab;
 
@@ -1015,3 +1160,18 @@ orz_mdi_reorder (OrzMdi *mdi,
                  tab->page_data);
   return TRUE;
 }
+
+
+/*  ja:ページの表示名を取得する
+         mdi,ウィジェット
+    page_num,ページ(0...),-1:カレント
+         RET,表示名                                                         */
+const gchar *
+orz_mdi_get_display_name (OrzMdi     *mdi,
+                          const gint  page_num)
+{
+  OrzMdiTab *tab;
+
+  tab = orz_mdi_get_tab (mdi, page_num);
+  return tab ? gtk_label_get_text (GTK_LABEL (tab->label)) : NULL;
+}
