@@ -1,6 +1,6 @@
 /*
     orzwinmenu
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "orzwinmenu.h"
 
@@ -63,7 +63,7 @@ orz_winmenu_class_init (OrzWinmenuClass *klass)
   GObjectClass *object_class;
 
   parent_class = g_type_class_peek_parent (klass);
-  object_class = (GObjectClass *) klass;
+  object_class = (GObjectClass *)klass;
 
   object_class->dispose = orz_winmenu_dispose;
 }
@@ -118,8 +118,12 @@ orz_winmenu_add (OrzMdi     *mdi,
 
       glist = gtk_container_get_children (GTK_CONTAINER (winmenu->menu_shell));
       length = g_list_length (glist);
+#if GLIB_CHECK_VERSION(2,6,0)
+      label = g_filename_display_name (orz_mdi_get_file (mdi, page_num));
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
       label = g_filename_to_utf8 (orz_mdi_get_file (mdi, page_num), -1,
                                                             NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
       menu_item = glist ? gtk_radio_menu_item_new_with_label_from_widget
                                     (GTK_RADIO_MENU_ITEM (glist->data), label)
                         : gtk_radio_menu_item_new_with_label (NULL, label);
@@ -205,8 +209,12 @@ orz_winmenu_change (OrzMdi     *mdi,
       GtkWidget *child;
 
       child = gtk_notebook_get_nth_page (GTK_NOTEBOOK (mdi), page_num);
+#if GLIB_CHECK_VERSION(2,6,0)
+      label = g_filename_display_name (orz_mdi_get_file (mdi, page_num));
+#else /* not GLIB_CHECK_VERSION(2,6,0) */
       label = g_filename_to_utf8 (orz_mdi_get_file (mdi, page_num), -1,
                                                             NULL, NULL, NULL);
+#endif /* not GLIB_CHECK_VERSION(2,6,0) */
       for (i = g_list_length (winmenu->glist) - 1; i >= 0; i--)
         {
           GtkWidget *menu_item;
@@ -449,7 +457,7 @@ orz_winmenu_destroy_menu_shell (GtkWidget  *widget,
 ******************************************************************************/
 /*  ja:新規作成
     RET,オブジェクト                                                        */
-GObject*
+GObject *
 orz_winmenu_new (void)
 {
   return g_object_new (ORZ_TYPE_WINMENU, NULL);
@@ -489,6 +497,16 @@ orz_winmenu_destroy_menu (OrzWinmenu *winmenu)
 }
 
 
+/*  ja:MDIを取得する
+    winmenu,オブジェクト
+        RET,MDI                                                             */
+OrzMdi *
+orz_winmenu_get_mdi (OrzWinmenu *winmenu)
+{
+  return winmenu ? winmenu->mdi : NULL;
+}
+
+
 /*  ja:MDIを設定する
     winmenu,オブジェクト
        mdi,MDI                                                              */
@@ -559,6 +577,16 @@ orz_winmenu_set_mdi (OrzWinmenu *winmenu,
 }
 
 
+/*  ja:メニューを取得する
+    winmenu,オブジェクト
+        RET,メニュー                                                        */
+GtkWidget *
+orz_winmenu_get_menu (OrzWinmenu *winmenu)
+{
+  return winmenu ? winmenu->menu_shell : NULL;
+}
+
+
 /*  ja:メニューを設定する
        winmenu,オブジェクト
     menu_shell,メニュー
@@ -566,7 +594,7 @@ orz_winmenu_set_mdi (OrzWinmenu *winmenu,
 void
 orz_winmenu_set_menu (OrzWinmenu *winmenu,
                       GtkWidget   *menu_shell,
-                      gint         position)
+                      const gint   position)
 {
   if (winmenu)
     {
