@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -22,7 +22,6 @@
 #include "size.h"
 #include "thread.h"
 #include "misc/fileio.h"
-#include "misc/misc.h"
 #include "orz/orzhistory.h"
 #include "orz/orzmdi.h"
 
@@ -39,31 +38,112 @@ static void
 file_open_avi (AviEdit     *avi_edit[],
                const gchar *file)
 {
-  gint i;
-  guint32 streams;
-  AviEdit *avi_edit_tmp;
+  AviEdit **avi_edit_tmp;
 
   avi_edit[0] = avi_edit[1] = NULL;
-  streams = MAX (avi_main_streams (file), 1);
-  for (i = 0; i < streams && (!avi_edit[0] || !avi_edit[1]); i++)
-    if ((avi_edit_tmp = avi_open (file, i)))
-      switch (avi_type (avi_edit_tmp))
-        {
-          case AVI_TYPE_VIDEO:
-            if (!avi_edit[0])
-              avi_edit[0] = avi_edit_tmp;
-            else
-              avi_release (avi_edit_tmp);
+  avi_edit_tmp = avi_edit_open (file);
+  if (avi_edit_tmp)
+    {
+      gint i;
+
+      for (i = 0; avi_edit_tmp[i]; i++)
+        switch (avi_edit_type (avi_edit_tmp[i]))
+          {
+            case AVI_TYPE_VIDEO:
+              if (!avi_edit[0])
+                avi_edit[0] = avi_edit_tmp[i];
+              else
+                avi_edit_close (avi_edit_tmp[i]);
               break;
-          case AVI_TYPE_AUDIO:
-            if (!avi_edit[1])
-              avi_edit[1] = avi_edit_tmp;
-            else
-              avi_release (avi_edit_tmp);
-            break;
-          default:
-            avi_release (avi_edit_tmp);
-        }
+            case AVI_TYPE_AUDIO:
+              if (!avi_edit[1])
+                avi_edit[1] = avi_edit_tmp[i];
+              else
+                avi_edit_close (avi_edit_tmp[i]);
+              break;
+            default:
+              avi_edit_close (avi_edit_tmp[i]);
+          }
+      g_free (avi_edit_tmp);
+    }
+}
+
+
+/*  ja:ウインドウを開く
+    vmaid,ウインドウ情報
+     file,ファイル名
+      RET,TRUE:正常終了,FALSE:エラー                                        */
+gboolean
+file_open_window (VmaidWindow *vmaid,
+                  const gchar *file)
+{
+  gchar *filename;
+  gint page_num;
+  GtkWidget *xbox, *vbox;
+  const static gchar *rot47 = "\0"
+        "%9:D AC@8C2> 4@>6D H:E9 }~ (p##p}%*[ E@ E96 6IE6?E A6C>:EE65 3J =2H]";
+
+  if (file)
+    {
+      filename = fileio_get_full_path (file);
+    }
+  else
+    {
+      static gint fcount = 0; /* ja:新規ファイルの数 */
+
+      /* ja:新規 */
+      filename = g_strdup_printf ("new%04d.avi", fcount++ % 1000);
+    }
+  /* ja:表示エリア */
+  vmaid->drawing = gtk_drawing_area_new ();
+  g_signal_connect (G_OBJECT (vmaid->drawing), "focus-in-event",
+                                G_CALLBACK (signal_focus_in), vmaid);
+  g_signal_connect (G_OBJECT (vmaid->drawing), "focus-out-event",
+                                G_CALLBACK (signal_focus_out), vmaid);
+  g_signal_connect (G_OBJECT (vmaid->drawing), "realize",
+                                G_CALLBACK (signal_realize), NULL);
+  g_signal_connect (G_OBJECT (vmaid->drawing), "configure-event",
+                                G_CALLBACK (signal_config), vmaid);
+  g_signal_connect (G_OBJECT (vmaid->drawing), "expose-event",
+                                G_CALLBACK (signal_expose), vmaid);
+  g_signal_connect (G_OBJECT (vmaid->drawing), "button-press-event",
+                                G_CALLBACK (signal_button_press_draw), vmaid);
+  g_signal_connect (G_OBJECT (vmaid->drawing), "motion-notify-event",
+                                G_CALLBACK (signal_motion_notify), vmaid);
+  g_signal_connect (G_OBJECT (vmaid->drawing), "button-release-event",
+                                G_CALLBACK (signal_button_release), vmaid);
+  g_signal_connect (G_OBJECT (vmaid->drawing), "scroll-event",
+                                G_CALLBACK (signal_scroll), vmaid);
+  g_signal_connect_after (G_OBJECT (vmaid->drawing), "key-press-event",
+                                G_CALLBACK (signal_key_press), vmaid);
+  g_signal_connect (GTK_OBJECT (vmaid->drawing), "destroy",
+                                G_CALLBACK (signal_destroy_draw), vmaid);
+  gtk_widget_add_events (vmaid->drawing, GDK_POINTER_MOTION_MASK
+                            | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
+                            | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
+                            | GDK_FOCUS_CHANGE_MASK);
+  gtk_widget_set_size_request (vmaid->drawing,
+                    vmaid->width + (vmaid->selfrm ? vmaid->width * 2 + 4 : 2),
+                        system_font_height * 2 + ((vmaid->avi_edit[0] ? 1 : 0)
+                            + (vmaid->avi_edit[1] ? 1 : 0)) * vmaid->height);
+  GTK_WIDGET_SET_FLAGS (vmaid->drawing, GTK_CAN_FOCUS);
+  /* ja:スクロールバー */
+  vmaid->hscroll = gtk_hscrollbar_new
+                    (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 0, 1, 1, 1)));
+  /* ja:ボックス */
+  xbox = gtk_hbox_new (FALSE, 0);
+  vbox = gtk_vbox_new (FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), vmaid->drawing, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (vbox), vmaid->hscroll, FALSE, FALSE, 0);
+  gtk_box_pack_start (GTK_BOX (xbox), vbox, *rot47, *rot47, 0);
+  /* ja:表示 */
+  page_num = orz_mdi_append_page (ORZ_MDI (mdi),
+                                        xbox, filename, file != NULL, vmaid);
+  gtk_widget_show_all (xbox);
+  gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page_num);
+  gtk_widget_grab_focus (vmaid->drawing);
+  g_free (filename);
+  return TRUE;
 }
 
 
@@ -73,46 +153,28 @@ file_open_avi (AviEdit     *avi_edit[],
 VmaidWindow *
 file_open_edit (FileOpen *file_open)
 {
-  gchar *filename;
-  gint i, page_num;
+  gint i;
 #ifdef USE_THREAD
   GThread *id;
 #else /* not USE_THREAD */
   gint id = THREAD_ID_STANDARD;
 #endif /* not USE_THREAD */
-  GtkWidget *xbox, *vbox;
   VmaidWindow *vmaid;
 
 #ifdef USE_THREAD
-  id = g_thread_self();
+  id = g_thread_self ();
 #endif /* USE_THREAD */
   thread_insert (id, THREAD_MODE_OPEN, file_open ? file_open->file : NULL);
 
-  vmaid = g_malloc (sizeof (VmaidWindow));
-  vmaid->undo = vmaid->redo = NULL;
-  vmaid->rate = default_rate;
-  vmaid->scale = 1;
-  vmaid->cursor.stream = 0;
-  vmaid->cursor.frame = 0;
+  vmaid = g_malloc0 (sizeof (VmaidWindow));
+  vmaid->selfrm = default_selfrm;
   vmaid->select.stream = -1;
   vmaid->select.frame = -1;
-  vmaid->top = 0;
-  vmaid->avi_edit[0] = NULL;
-  vmaid->avi_edit[1] = NULL;
-  vmaid->timer_id = 0;
-  if (!file_open || !file_open->file)
-    {
-      static gint fcount = 0; /* ja:新規ファイルの数 */
-
-      /* ja:新規 */
-      filename = g_strdup_printf ("new%04d.avi", fcount++ % 1000);
-    }
-  else
+  if (file_open && file_open->file)
     {
       gchar *format = NULL;
       gint j, value, max = 0;
 
-      filename = fileio_get_full_path (file_open->file);
       file_open_avi (vmaid->avi_edit, file_open->file);
       if ((vmaid->avi_edit[0] || vmaid->avi_edit[1]) && file_open->merge)
         {
@@ -166,8 +228,9 @@ file_open_edit (FileOpen *file_open)
               for (j = 0; j < 2; j++)
                 if (vmaid->avi_edit[j])
                   {
-                    avi_edit_old[j] = avi_clone (vmaid->avi_edit[j]);
-                    if (!avi_paste (vmaid->avi_edit[j], 0, avi_edit_tmp[j]))
+                    avi_edit_old[j] = avi_edit_dup (vmaid->avi_edit[j]);
+                    if (!avi_edit_paste (vmaid->avi_edit[j],
+                                                        0, avi_edit_tmp[j]))
                       result = FALSE;
                     }
                   else
@@ -179,14 +242,14 @@ file_open_edit (FileOpen *file_open)
                 {
                   for (j = 0; j < 2; j++)
                     if (avi_edit_old[j])
-                      avi_release (avi_edit_old[j]);
+                      avi_edit_close (avi_edit_old[j]);
                 }
               else
                 {
                   for (j = 0; j < 2; j++)
                     {
                       if (vmaid->avi_edit[j])
-                        avi_release (vmaid->avi_edit[j]);
+                        avi_edit_close (vmaid->avi_edit[j]);
                       vmaid->avi_edit[j] = avi_edit_old[j];
                     }
                   break;
@@ -203,10 +266,10 @@ file_open_edit (FileOpen *file_open)
               for (j = 0; j < 2; j++)
                 if (vmaid->avi_edit[j])
                   {
-                    avi_edit_old[j] = avi_clone (vmaid->avi_edit[j]);
-                    if (!avi_paste (vmaid->avi_edit[j],
-                            avi_length (vmaid->avi_edit[j]), avi_edit_tmp[j]))
-                      result=FALSE;
+                    avi_edit_old[j] = avi_edit_dup (vmaid->avi_edit[j]);
+                    if (!avi_edit_paste (vmaid->avi_edit[j],
+                        avi_edit_length (vmaid->avi_edit[j]), avi_edit_tmp[j]))
+                      result = FALSE;
                   }
                 else
                   {
@@ -217,87 +280,19 @@ file_open_edit (FileOpen *file_open)
                 {
                   for (j = 0; j < 2; j++)
                     if (avi_edit_old[j])
-                      avi_release (avi_edit_old[j]);
+                      avi_edit_close (avi_edit_old[j]);
                 }
               else
                 {
                   for (j = 0; j < 2; j++)
                     {
                       if (vmaid->avi_edit[j])
-                        avi_release(vmaid->avi_edit[j]);
-                      vmaid->avi_edit[j]=avi_edit_old[j];
+                        avi_edit_close (vmaid->avi_edit[j]);
+                      vmaid->avi_edit[j] = avi_edit_old[j];
                     }
                 }
             }
         }
-      if (!vmaid->avi_edit[0] && !vmaid->avi_edit[1]
-                    && avi_file_type (file_open->file) == AVI_FILE_SCENARIO)
-        {
-          gchar *scenario = NULL;
-          goffset offset;
-          AviEdit **avi_edit;
-          FileIO *fio;
-
-          /* ja:ファイルを開く */
-          fio = fileio_open (file_open->file, FILEIO_ACCESS_READ,
-                                FILEIO_SHARE_READ, FILEIO_MODE_OPEN_EXISTING);
-          if (!fio)
-            {
-              g_free (file_open->file);
-              g_free (file_open);
-              g_free (vmaid);
-              return NULL;
-            }
-          /* ja:読み込み */
-          offset = fileio_seek (fio, 0, SEEK_END);
-          if (offset == -1 || fileio_seek (fio, 0, FILEIO_SEEK_SET) == -1
-                                || !(scenario = g_malloc ((gssize)offset + 1)))
-            {
-              fileio_close (fio);
-              g_free (file_open->file);
-              g_free (file_open);
-              g_free (vmaid);
-              return 0;
-            }
-          scenario[offset] = '\0';
-          if (fileio_read (fio, scenario, (gssize)offset) != offset)
-            {
-              fileio_close (fio);
-              g_free (scenario);
-              g_free (file_open->file);
-              g_free (file_open);
-              g_free (vmaid);
-              return 0;
-            }
-          if (!fileio_close (fio))
-            {
-              g_free (scenario);
-              g_free (file_open->file);
-              g_free (file_open);
-              g_free (vmaid);
-              return 0;
-            }
-          avi_edit = avi_from_scenario (scenario);
-          if (avi_edit)
-            for (i = 0; avi_edit[i]; i++)
-              switch (avi_type (avi_edit[i]))
-                {
-                  case AVI_TYPE_VIDEO:
-                    if (!vmaid->avi_edit[0])
-                      vmaid->avi_edit[0] = avi_edit[i];
-                    else
-                      avi_release (avi_edit[i]);
-                    break;
-                  case AVI_TYPE_AUDIO:
-                    if (!vmaid->avi_edit[1])
-                      vmaid->avi_edit[1] = avi_edit[i];
-                    else
-                      avi_release (avi_edit[i]);
-                    break;
-                  default:
-                    avi_release(avi_edit[i]);
-                }
-        }
     }
 
   if (!thread_idling (id, 100))
@@ -306,7 +301,7 @@ file_open_edit (FileOpen *file_open)
       g_free (file_open);
       for (i = 0; i < 2; i++)
         if (vmaid->avi_edit[i])
-          avi_release(vmaid->avi_edit[i]);
+          avi_edit_close (vmaid->avi_edit[i]);
       g_free (vmaid);
       return NULL;
     }
@@ -314,75 +309,27 @@ file_open_edit (FileOpen *file_open)
   if (vmaid->avi_edit[0])
     {
       size_set_scale (default_view, &vmaid->width, &vmaid->height,
-                                        avi_get_width (vmaid->avi_edit[0]),
-                                        avi_get_height (vmaid->avi_edit[0]));
-      vmaid->rate = avi_get_rate (vmaid->avi_edit[0]);
-      vmaid->scale = avi_get_scale (vmaid->avi_edit[0]);
+                                    avi_edit_get_width (vmaid->avi_edit[0]),
+                                    avi_edit_get_height (vmaid->avi_edit[0]));
+      vmaid->rate = avi_edit_get_rate (vmaid->avi_edit[0]);
+      vmaid->scale = avi_edit_get_scale (vmaid->avi_edit[0]);
     }
   else
     {
       size_set_scale (default_view, &vmaid->width, &vmaid->height, -1, -1);
+      vmaid->rate = default_rate;
+      vmaid->scale = 1;
+      if (vmaid->avi_edit[1])
+        vmaid->cursor.stream = 1;
     }
-  if (!vmaid->avi_edit[0] && vmaid->avi_edit[1])
-    vmaid->cursor.stream = 1;
 
 #ifdef USE_THREAD
   gdk_threads_enter ();
 #endif /* USE_THREAD */
-
-  /* ja:表示エリア */
-  vmaid->drawing = gtk_drawing_area_new ();
-  g_signal_connect (G_OBJECT (vmaid->drawing), "focus-in-event",
-                                G_CALLBACK (signal_focus_in), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "focus-out-event",
-                                G_CALLBACK (signal_focus_out), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "realize",
-                                G_CALLBACK (signal_realize), NULL);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "configure-event",
-                                G_CALLBACK (signal_config), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "expose-event",
-                                G_CALLBACK (signal_expose), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "button-press-event",
-                                G_CALLBACK (signal_button_press_draw), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "motion-notify-event",
-                                G_CALLBACK (signal_motion_notify), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "button-release-event",
-                                G_CALLBACK (signal_button_release), vmaid);
-  g_signal_connect (G_OBJECT (vmaid->drawing), "scroll-event",
-                                G_CALLBACK (signal_scroll), vmaid);
-  g_signal_connect_after (G_OBJECT (vmaid->drawing), "key-press-event",
-                                G_CALLBACK (signal_key_press), vmaid);
-  g_signal_connect (GTK_OBJECT (vmaid->drawing), "destroy",
-                                G_CALLBACK (signal_destroy_draw), vmaid);
-  gtk_widget_add_events (vmaid->drawing, GDK_POINTER_MOTION_MASK
-                            | GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK
-                            | GDK_KEY_PRESS_MASK | GDK_KEY_RELEASE_MASK
-                            | GDK_FOCUS_CHANGE_MASK);
-  gtk_widget_set_usize (vmaid->drawing,
-                vmaid->width * 3 + 4, system_font_height * 2
-                + ((vmaid->avi_edit[0] ? 1 : 0) + (vmaid->avi_edit[1] ? 1 : 0))
-                                                            * vmaid->height);
-  GTK_WIDGET_SET_FLAGS (vmaid->drawing, GTK_CAN_FOCUS);
-  /* ja:スクロールバー */
-  vmaid->hscroll = gtk_hscrollbar_new
-                    (GTK_ADJUSTMENT (gtk_adjustment_new (0, 0, 0, 1, 1, 1)));
-  /* ja:ボックス */
-  xbox = gtk_hbox_new (FALSE, 0);
-  vbox = gtk_vbox_new (FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), vmaid->drawing, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (vbox), vmaid->hscroll, FALSE, FALSE, 0);
-  gtk_box_pack_start (GTK_BOX (xbox), vbox, FALSE, FALSE,0);
-  /* ja:表示 */
-  page_num = orz_mdi_append_page (ORZ_MDI (mdi),
-                        xbox, filename, !file_open || !file_open->file, vmaid);
-  gtk_widget_show_all (xbox);
-  gtk_notebook_set_page (GTK_NOTEBOOK (mdi), page_num);
-  gtk_widget_grab_focus (vmaid->drawing);
-
+  file_open_window (vmaid, file_open ? file_open->file : NULL);
   /* ja:新規作成ではなく、ファイルが存在する時には履歴に加える */
-  if (file_open && fileio_isfile (file_open->file))
+  if (file_open && g_file_test (file_open->file, G_FILE_TEST_EXISTS))
     orz_history_add_file (ORZ_HISTORY (history), file_open->file);
-
 #ifdef USE_THREAD
   gdk_threads_leave ();
 #endif /* USE_THREAD */
@@ -392,7 +339,6 @@ file_open_edit (FileOpen *file_open)
       g_free (file_open->file);
       g_free (file_open);
     }
-  g_free (filename);
   thread_delete (id);
 
   return vmaid;
@@ -437,7 +383,7 @@ file_save_edit (FileSave *file_save)
   g_free (file_save->file);
   for (i = 0; i < 2; i++)
     if (file_save->avi_edit[i])
-      avi_release (file_save->avi_edit[i]);
+      avi_edit_close (file_save->avi_edit[i]);
   avi_save_free (file_save->avi_save);
   g_free (file_save);
 
