@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -102,25 +102,10 @@ signal_drag_data_received (GtkWidget        *widget,
                            guint             time);
 
 
-gboolean
-signal_selection_clear (GtkWidget         *widget,
-                        GdkEventSelection *event,
-                        gpointer           user_data);
-
-
 void
-signal_selection_get (GtkWidget        *widget,
-                      GtkSelectionData *data,
-                      guint             info,
-                      guint             time,
-                      gpointer          user_data);
-
-
-void
-signal_selection_received (GtkWidget        *widget,
-                           GtkSelectionData *data,
-                           guint             time,
-                           gpointer          user_data);
+signal_selection_paste (GObject   *object,
+                        AviEdit  **avi_edit,
+                        gpointer   user_data);
 
 
 void
