@@ -156,7 +156,7 @@ thread_insert (gint         id,
     }
   /* ja:ファイル名 */
 #if GTK_CHECK_VERSION(2,8,0)
-  pixbuf_file = fileio_extract_icon (file, FILEIO_ICON_SIZE_SMALL);
+  pixbuf_file = fileio_extract_icon (file, GTK_ICON_SIZE_MENU);
 #endif /* GTK_CHECK_VERSION(2,8,0) */
 #if GLIB_CHECK_VERSION(2,6,0)
   text_file = file ? g_filename_display_name (file) : NULL;
