@@ -1,6 +1,6 @@
 /*
     Video maid
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -16,11 +16,11 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
+#include "icons.h"
 #include "version.h"
 #include "avicore/acm.h"
 #include "avicore/icm.h"
 #include "misc/gnugpl.h"
-#include <gdk/gdkkeysyms.h>
 
 
 /******************************************************************************
@@ -78,9 +78,9 @@ version_dialog_clicked (GtkWidget        *widget,
 
       gtk_tree_model_get (model, &iter, 3, &icm_object, 4, &acm_object, -1);
       if (icm_object)
-        icm_dialog_about (icm_object);
+        icm_dialog_about (icm_object, gtk_widget_get_toplevel (widget));
       else if (acm_object)
-        acm_dialog_about (acm_object);
+        acm_dialog_about (acm_object, gtk_widget_get_toplevel (widget));
     }
 }
 
@@ -89,7 +89,7 @@ version_dialog_clicked (GtkWidget        *widget,
 static gboolean
 version_dialog_button_press (GtkWidget      *widget,
                              GdkEventButton *event,
-                             gpointer        user_data)
+                             GtkWidget      *button)
 {
   gboolean result = FALSE;
 
@@ -105,8 +105,7 @@ version_dialog_button_press (GtkWidget      *widget,
           if (gtk_tree_model_get_iter (gtk_tree_view_get_model
                                         (GTK_TREE_VIEW (widget)), &iter, path))
             {
-              version_dialog_clicked (widget,
-                        gtk_tree_view_get_selection (GTK_TREE_VIEW (widget)));
+              gtk_button_clicked (GTK_BUTTON (button));
               result = TRUE;
             }
           gtk_tree_path_free (path);
@@ -116,18 +115,6 @@ version_dialog_button_press (GtkWidget      *widget,
 }
 
 
-/* ja:ESCが押された */
-static gboolean
-version_dialog_key_press (GtkWidget   *widget,
-                          GdkEventKey *event,
-                          gpointer     user_data)
-{
-  if (event->keyval == GDK_Escape)
-    gtk_dialog_response (GTK_DIALOG (widget), GTK_RESPONSE_NONE);
-  return FALSE;
-}
-
-
 void
 version_dialog (void)
 {
@@ -144,75 +131,24 @@ version_dialog (void)
   GtkWidget *dialog, *scroll, *hbox0, *hbox1 ,*vbox;
   const static gchar *str[3] = {N_("Name"), N_("Code"), N_("Attribute")};
   const static gchar *authors =
-"Main Program :\n"
-"    Kazuki IWAMOTO\n"
-"Document :\n"
+"Supreme Programmer:\n"
+" Kazuki IWAMOTO <iwm@maid.org>\n"
 "\n"
-"Logo :\n"
+"Codecs Author:\n"
+" ryoma <ryoma@users.sourceforge.jp>\n"
 "\n"
-"Translate :\n"
+"Icons Author:\n"
+" from GTK+ Stock Icons\n"
 "\n"
-"dllloader :\n"
-"    Hiroshi Takekawa\n"
-"Packager :\n"
-"    yasuo-s\n"
-"Special Thanks :\n"
-"    midori\n"
-"    MINAMI Hirokazu\n"
-"    Takuro Ashie\n"
-"    ryoma\n"
-"    And all Video maid users";
-/* XPM */
-const static gchar *vmaid_xpm[] = {
-"32 32 16 1",
-"   c None",
-".  c #000000",
-"+  c #800000",
-"@  c #008000",
-"#  c #808000",
-"$  c #000080",
-"%  c #800080",
-"&  c #008080",
-"*  c #808080",
-"=  c #C0C0C0",
-"-  c #FF0000",
-";  c #00FF00",
-">  c #FFFF00",
-",  c #0000FF",
-"'  c #FF00FF",
-")  c #00FFFF",
-"                                ",
-"                                ",
-"++++++++++++++++++++++++++++++++",
-" ++   ++   ++   ++   ++   ++   +",
-" ++   ++   ++   ++   ++   ++   +",
-" ++   ++   ++   ++   ++   ++   +",
-"++++++++++++++++++++++++++++++++",
-". . + . . . . . . . . . . .+. . ",
-" . .+. . . . . ' . . . . . + . .",
-". . + . . . . ''  . . . . .+. . ",
-" . .+. . . . ''' . . . . . + . .",
-". . + . . .  '''      . . .+. . ",
-" . .+. . -  '''',,,,,, . . + . .",
-". . + .  ---'''',,,,, . . .+. . ",
-" . .+. .  ----'',,,) . . . + . .",
-". . + . . -----',)))  . . .+. . ",
-" . .+. . . --->;)))))  . . + . .",
-". . + . .  ->>>;;)))) . . .+. . ",
-" . .+. .  >>>>>;;;;))) . . + . .",
-". . + .  >>>>>>;;;;  )  . .+. . ",
-" . .+. .       ;;; .   . . + . .",
-". . + . . . .  ;;;  . . . .+. . ",
-" . .+. . . . . ;;  . . . . + . .",
-". . + . . . .  ;  . . . . .+. . ",
-" . .+. . . . .   . . . . . + . .",
-"++++++++++++++++++++++++++++++++",
-" ++   ++   ++   ++   ++   ++   +",
-" ++   ++   ++   ++   ++   ++   +",
-" ++   ++   ++   ++   ++   ++   +",
-"++++++++++++++++++++++++++++++++",
-"                                ",
-"                                "};
+"Packager:\n"
+" yasuo-s\n"
+"\n"
+"Special Thanks:\n"
+" MINAMI Hirokazu\n"
+" Takuro Ashie\n"
+" midori\n"
+" MATSUU Takuto\n"
+" And all Video maid users";
 
   /* ja:メインウインドウ */
   dialog = gtk_dialog_new_with_buttons
@@ -225,7 +161,7 @@ const static gchar *vmaid_xpm[] = {
   gtk_window_set_default_size (GTK_WINDOW (dialog),
                     gdk_screen_width () * 2 / 3, gdk_screen_height () * 2 / 3);
   g_signal_connect (G_OBJECT (dialog), "key-press-event",
-                                G_CALLBACK (version_dialog_key_press), NULL);
+                                    G_CALLBACK (misc_dialog_key_press), NULL);
   /* ja:ノートブック */
   notebook = gtk_notebook_new ();
   gtk_notebook_set_scrollable (GTK_NOTEBOOK (notebook), TRUE);
@@ -263,11 +199,15 @@ const static gchar *vmaid_xpm[] = {
   gtk_container_add (GTK_CONTAINER (scroll), text);
   /* ja:ノートブック */
   gtk_notebook_append_page (GTK_NOTEBOOK (notebook), scroll,
-                                                gtk_label_new (_("Authors")));
+                                gtk_label_new (_("Authors & Contributors")));
 
   /* ja:プラグイン */
   /* ja:ボタン */
+#if GTK_CHECK_VERSION(2,6,0)
+  button = gtk_button_new_from_stock (GTK_STOCK_ABOUT);
+#else /* not GTK_CHECK_VERSION(2,6,0) */
   button = gtk_button_new_with_mnemonic (_("_About..."));
+#endif /* not GTK_CHECK_VERSION(2,6,0) */
   /* ja:ツリービュー */
   store = gtk_tree_store_new (5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
                                             G_TYPE_POINTER, G_TYPE_POINTER);
@@ -420,7 +360,7 @@ const static gchar *vmaid_xpm[] = {
   g_signal_connect (G_OBJECT (store), "row-deleted",
                             G_CALLBACK (version_dialog_row_deleted), NULL);
   g_signal_connect (G_OBJECT (tview), "button-press-event",
-                            G_CALLBACK (version_dialog_button_press), NULL);
+                            G_CALLBACK (version_dialog_button_press), button);
   gtk_widget_add_events (tview, GDK_BUTTON_PRESS_MASK);
   g_object_unref (G_OBJECT (store));
   /* ja:スクロールウインドウ */
@@ -432,7 +372,6 @@ const static gchar *vmaid_xpm[] = {
   g_signal_connect (G_OBJECT (button), "clicked",
                                 G_CALLBACK (version_dialog_clicked), select);
   gtk_widget_set_sensitive (button, FALSE);
-  GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   /* ja:フレームとボックス */
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_box_pack_start (GTK_BOX (vbox), scroll, TRUE, TRUE, 0);
@@ -447,7 +386,7 @@ const static gchar *vmaid_xpm[] = {
   vbox = gtk_vbox_new (FALSE, SPACING);
   gtk_container_set_border_width (GTK_CONTAINER (vbox), SPACING);
   hbox0 = gtk_hbox_new (FALSE, SPACING);
-  pixbuf = gdk_pixbuf_new_from_xpm_data (vmaid_xpm);
+  pixbuf = gdk_pixbuf_new_from_xpm_data (vmaid32_xpm);
   gtk_box_pack_start (GTK_BOX (hbox0),
                         gtk_image_new_from_pixbuf (pixbuf), FALSE, FALSE, 0);
   g_object_unref (pixbuf);
