@@ -1,6 +1,6 @@
 /*
     w32loader
-    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2006 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -58,9 +58,10 @@ extern "C" {
 typedef gint32      BOOL,   *PBOOL,   *LPBOOL;
 typedef void        VOID,   *PVOID,   *LPVOID;
 typedef const void  CVOID,  *PCVOID,  *LPCVOID;
-typedef gint8       CHAR,   *PCHAR,   *LPCHAR,   *CHAR_PTR;
-typedef guint8      UCHAR,  *PUCHAR,  *LPUCHAR,  *UCHAR_PTR;
-typedef guint16     WCHAR,  *PWCHAR,  *LPWCHAR,  *WCHAR_PTR;
+typedef gchar       CHAR,   *PCHAR,   *LPCHAR,   *CHAR_PTR;
+typedef guchar      UCHAR,  *PUCHAR,  *LPUCHAR,  *UCHAR_PTR;
+typedef gunichar2   WCHAR,  *PWCHAR,  *LPWCHAR,  *WCHAR_PTR;
+typedef gunichar2   WUCHAR, *PWUCHAR, *LPWUCHAR, *WUCHAR_PTR;
 typedef gint16      SHORT,  *PSHORT,  *LPSHORT,  *SHORT_PTR;
 typedef guint16     USHORT, *PUSHORT, *LPUSHORT, *USHORT_PTR;
 typedef gint32      INT,    *PINT,    *LPINT,    *INT_PTR;
