@@ -180,8 +180,8 @@ HDRVR WINAPI OpenDriver (LPCWSTR lpDriverName, LPCWSTR lpSectionName, LONG lPara
 
       WideCharToMultiByte (CP_ACP, 0, lpDriverName, -1,
                                                 szName, MAX_PATH, NULL, NULL);
-      if (RegQueryValueEx (hKey, szName, NULL, &dwType, szValue, &dwValue)
-                                        == ERROR_SUCCESS && dwType == REG_SZ)
+      if (RegQueryValueEx (hKey, szName, NULL, &dwType,
+            (LPBYTE)szValue, &dwValue) == ERROR_SUCCESS && dwType == REG_SZ)
         {
           file = w32ldr_filename_from_mb (szValue);
 #endif
